@@ -1,7 +1,7 @@
-# copyright (C) 1997-98 Jean-Luc Fontaine (mailto:jfontain@mygale.org)
+# copyright (C) 1997-98 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: help.tcl,v 1.25 1998/10/11 09:32:49 jfontain Exp $}
+set rcsId {$Id: help.tcl,v 1.26 1998/11/17 21:05:35 jfontain Exp $}
 
 namespace eval help {
 
@@ -19,7 +19,7 @@ This program is distributed in the hope that it will be useful, but WITHOUT ANY
 
 (see Copyright under the Help menu for more details)
 
-        jfontain@mygale.org
+        jfontain@multimania.com
 
 
 This software includes the Tcl HTML library developped by Sun Microsystems and made available under the following license terms:
