@@ -103,6 +103,9 @@ as module data may change on its own). Note that any number of asynchronous
 and regular (synchronous) modules can be simultaneously loaded.
 <P>Versions 5.0 and up add a free text viewer, which can be used for comments,
 and which can also embed live data cells in text form.
+<P>Versions 5.3 and up support viewer type mutation through viewer icon
+drag'n'drop, and viewer quick destruction through trash icon drag'n'drop
+operation. A new menu for empty viewer creation was also added.
 <P>Since module data access is entirely customizable (through C code, Tcl,
 HTTP, ...) and since several modules can be loaded at once, applications
 for moodss become limitless. For example, comparing a remote database server
@@ -112,7 +115,8 @@ possible.
 be made available while the module structure will stay the same. The goal
 of moodss is to become a nice feature packed generic way of viewing data.
 Moodss can be used to monitor any type of data, since the simplest cases
-can fit in a table with a single row.
+can fit in one table with a single row, with the most complicated requiring
+loading several multiple table modules.
 <P>As moodss is written in Tcl and uses well supported extensions (Tktable
 and BLT), it will run on Tcl/Tk supported platforms: UNIX and Windows (I
 do not know if Tktable and BLT are available for the MacIntosh). Obviously,
@@ -128,10 +132,10 @@ menu for more information.
 <A NAME="required"></A>3. Required software</H3>
 If you are using a Linux Redhat system (5.1 or above), then use the moodss
 rpm file (available (starting with 4.4) at <A HREF="http://www.multimania.com/jfontain/">http://www.multimania.com/jfontain/</A>)
-for installation. It includes all the required software and librairies
-(except Tcl/Tk 8.x, of course). Unless you want to work on the moodss source
-code, you can skip the rest of this section.
-<P>For the current version (5.2), the following packages must be installed
+for installation. It includes all the required software and libraries (except
+Tcl/Tk 8.x, of course). Unless you want to work on the moodss source code,
+you can skip the rest of this section.
+<P>For the current version (5.4), the following packages must be installed
 before attempting to install moodss (make sure to check the INSTALL file
 for the latest information):
 <UL>
@@ -139,7 +143,7 @@ for the latest information):
 Tcl/Tk version 8.0 or above (at <A HREF="http://sunscript.sun.com/">http://sunscript.sun.com/</A>)</LI>
 
 <LI>
-tkTable version 2.0 or above (at <A HREF="http://oprs.mchh.siemens.de/tcl/capp/tkTable/">http://oprs.mchh.siemens.de/tcl/capp/tkTable/</A>)<B>*</B></LI>
+tkTable version 2.3 or above (at <A HREF="http://oprs.mchh.siemens.de/tcl/capp/tkTable/">http://oprs.mchh.siemens.de/tcl/capp/tkTable/</A>)<B>*</B></LI>
 
 <LI>
 the BLT library version 2.4 (at <A HREF="ftp://ftp.tcltk.com/pub/blt/">ftp://ftp.tcltk.com/pub/blt/</A>)<B>*</B></LI>
@@ -187,16 +191,20 @@ the application table and eventual graphical viewers). If a module is synchronou
 it must start updating its data when requested by the core. If a module
 is asynchronous, its data may be updated at any time. The synchronous or
 asynchronous nature is specified in the configuration data for the module.
-<P>The initial data tables represent the first data views, from which cells
-can be selected and when dropped through a drag'n'drop operation into a
-graph, bar chart, pie chart, summary table or free text iconic site, resulting
-in the creation of data viewers. In turn, these viewers can display more
-table cells, which when dropped into the viewer, result in the creation
+<P>The initial data tables represent the first data views, from which any
+number of cells can be selected. Data viewers can be created by dropping
+cells through a drag'n'drop operation into a graph, bar chart, pie chart,
+summary table or free text iconic site. In turn, these viewers can display
+more table cells, which when dropped into the viewer, result in the creation
 of corresponding data graph lines, chart bars, pie slices, table rows or
 text cells. Cells or rows can be removed from existing viewers, by simply
 selecting them and dropping them in the trash iconic site (a bullet hole).
-<P>Any draggable data can be dropped in valid drop sites at any time. It
-is thus possible to drag several data cells from any table or any viewer
+<P>Any viewer can be mutated (its type changed) by dropping a viewer icon
+into it. For example, create a stacked data bar viewer from several cells,
+then drag the 3D pie drag'n'drop icon into it. Any viewer can also be destroyed
+in one shot by dropping the trash icon into it.
+<P>Any draggable data can be dropped in any valid drop site at any time.
+It is thus possible to drag several data cells from any table or any viewer
 into other ones, the trash, ... even if the data comes from different modules.
 <P>All data viewers can be moved and resized at will with the help of a
 simple internal window manager.
@@ -212,7 +220,7 @@ Soon after the application launch, tabular data is displayed in one or
 more tkTable widgets with automatic scroll bars, between the menu bar,
 the drop sites with graphical viewers, summary table, free text and trash
 icons and a message area, as one can see below:
-<CENTER><PRE><IMG SRC="moodss1.gif" ALT="moodss initial main window view" HEIGHT=445 WIDTH=475></PRE></CENTER>
+<CENTER><PRE><IMG SRC="moodss1.gif" ALT="moodss initial main window view" HEIGHT=501 WIDTH=501></PRE></CENTER>
 The message area is used to display status information, such as when the
 data is being updated, and help information, as the user moves the mouse
 pointer over sensitive areas, such as table column headers. Further help
@@ -226,7 +234,7 @@ or gracefully quit the moodss application.
 <P>The <I>Options</I> menu (may not exist, see below) contains the <I>Poll
 time</I> entry which when selected launches the corresponding dialog box,
 as shown below:
-<CENTER><PRE><IMG SRC="moodss2.gif" ALT="poll time dialog box" HEIGHT=129 WIDTH=165></PRE></CENTER>
+<CENTER><PRE><IMG SRC="moodss2.gif" ALT="poll time dialog box" HEIGHT=140 WIDTH=161></PRE></CENTER>
 The user can select a new poll time among the module choices from a spin
 entry widget, or directly type in a new value, as long as it is not smaller
 than the module minimum poll time, in which case a message dialog box warns
@@ -239,6 +247,9 @@ all modules poll times.
 <P>The <I>Poll time</I> menu entry is available only when needed, which
 is not the case if all the loaded modules are asynchronous. If this case,
 the <I>Options</I> menu itself is not displayed.
+<P>The <I>New</I> menu (only visible when not running in read-only mode,
+see <A HREF="#commandline">Command line</A>), allows the creation of empty
+viewers of any type.
 <P>Any data displayed in a table can be sorted at any time by simply clicking
 on a column title. Clicking on the same column title again sorts the data
 in opposite order, thus toggling between increasing and decreasing orders.
@@ -323,7 +334,7 @@ at any time.
 </TABLE></CENTER>
 Here is a screen shot of loaded <I>ps</I> and <I>cpustats</I> modules with
 several graphical viewers:
-<CENTER><PRE><IMG SRC="moodss3.gif" ALT="moodss window with graph data viewers" HEIGHT=506 WIDTH=516></PRE></CENTER>
+<CENTER><PRE><IMG SRC="moodss3.gif" ALT="moodss window with graph data viewers" HEIGHT=514 WIDTH=524></PRE></CENTER>
 All data viewers can be moved and resized thanks to handling areas in the
 data viewer borders. When moving the mouse pointer over these areas, the
 mouse cursor changes to indicate the possible action. Corner handles allow
@@ -339,7 +350,7 @@ small window manager functionality is useless, as it behaves like a basic
 window manager (let me know if it does not).
 <P>Here is another shot featuring a free text viewer with loaded <I>cpustats</I>
 and <I>memstats</I> modules:
-<CENTER><PRE><IMG SRC="moodss4.gif" ALT="moodss window with free text data viewer" HEIGHT=464 WIDTH=431></PRE></CENTER>
+<CENTER><PRE><IMG SRC="moodss4.gif" ALT="moodss window with free text data viewer" HEIGHT=480 WIDTH=459></PRE></CENTER>
 The <I>Help</I> menu contains <I>Global</I> help (actually launches an
 embedded HTML viewer with this very document), <I>Modules</I> help which
 displays all the loaded modules help texts, <I>Copyright</I> which displays
@@ -386,7 +397,7 @@ stacked bar chart with one or more data bars created at once</LI>
 summary table with one or more data rows created at once</LI>
 
 <LI>
-free text with one or more labelled data cell windows created at once</LI>
+free text with one or more labeled data cell windows created at once</LI>
 
 <LI>
 object trash with one or more data viewer elements deleted at once</LI>
@@ -407,11 +418,18 @@ the shift key along with the first mouse button. The pie slices can also
 be directly selected by clicking on the slices themselves.
 <BR>Then dragging from the viewer to the trash drop site (the bullet hole)
 on the upper right side of the main window and releasing the first mouse
-button result in the corresponding viewer elements to be destroyed. If
+button result in the corresponding viewer elements to be destroyed. When
 there are no remaining elements, the viewer itself (graph, bar chart, pie
-or summary table) is destroyed. The free text viewer can only be deleted
-when completely emptied of any text and data cell window: it can then be
-dropped into the trash.
+or summary table) can be destroyed by dropping it into the trash. The free
+text viewer can only be deleted this way when completely emptied of any
+text and data cell window.
+<P>Any viewer can be deleted in one shot by dropping from the trash icon
+into it.
+<P>Any viewer also acts as a drop site for viewer type data, which allows
+viewer mutation by just dropping from the new viewer type icon into the
+existing viewer. It is much quicker than destroying the existing viewer
+and create a new one of the new type, while remembering which data cells
+were monitored by the viewer of the old type.
 <H6>
 <A NAME="dragsites"></A>5.1.1.2. Drag sites</H6>
 A table is obviously a drag site. One or more cells can be dragged at once
@@ -423,6 +441,12 @@ in the viewer. If there are no selected elements, dragging is impossible:
 the mouse cursor is not changed into the drag circular cursor.
 <P>If a viewer contains no elements, then the viewer itself can be dragged
 and dropped into the trash.
+<P>All viewer icons (below the menu bar) are drag sites for viewer type
+data, which allows quick viewer mutation (see mechanism description in
+<A HREF="#dropsites">Drop
+sites</A>).
+<P>The trash icon is also a drag site of the killing action type, which
+allows viewer destruction in one shot.
 <H5>
 <A NAME="saving"></A>5.1.2 Saving</H5>
 The current application configuration (including existing data viewers)
@@ -460,7 +484,7 @@ For moodss version 5.1 and above, the following information is also saved:
 <LI>
 table viewers column widths</LI>
 </UL>
-For moodss version 5.1 and above, the following information is also saved:
+For moodss version 5.2 and above, the following information is also saved:
 <UL>
 <LI>
 viewers stacking order (for internal window manager)</LI>
@@ -492,12 +516,13 @@ configuration can be retrieved using:
 <PRE>$ wish moodss -f save.moo</PRE>
 which would result in the same modules being loaded, the same viewers displayed
 at the same positions and sizes, the same poll time being used, as well
-at the same application window size.
+at the same application window size. New modules data displays can be added
+at any latter time to existing dashboards by specifying modules on the
+command line after the -f (--file) switch / value pair.
 <P>Command line options include:
 <UL>
 <LI>
-<B>-f</B> (or <B>--file</B>): specifies a configuration file name (incompatible
-with modules)</LI>
+<B>-f</B> (or <B>--file</B>): specifies a configuration file name</LI>
 
 <LI>
 <B>-h</B> (or <B>--help</B>): displays some help text and exits</LI>
