@@ -11,15 +11,15 @@ wm group . .
 source utility.tcl
 startGatheringRCSIds
 
-set rcsId {$Id: moodss.tcl,v 1.118 1998/11/24 20:29:32 jfontain Exp $}
+set rcsId {$Id: moodss.tcl,v 1.128 1998/12/10 21:42:34 jfontain Exp $}
 
-set applicationVersion 5.2
+set applicationVersion 5.4
 
 source getopt.tcl
 
 proc printUsage {exitCode} {
     puts stderr "Usage: $::argv0 \[OPTION\]... \[MODULE\] \[MODULE\]..."
-    puts stderr {  -f, --file       configuration file name (implies no modules)}
+    puts stderr {  -f, --file       configuration file name}
     puts stderr {  -h, --help       display this help and exit}
     puts stderr {  -p, --poll-time  poll time in seconds}
     puts stderr {  -r, --read-only  disable viewer creation, editing, ...}
@@ -47,10 +47,7 @@ if {[info exists arguments(--version)]} {
     puts "moodss (a Modular Object Oriented Dynamic SpreadSheet) version $applicationVersion"
     exit
 }
-if {\
-    ([info exists arguments(-f)]&&([llength $argv]>0))||(![info exists arguments(-f)]&&([llength $argv]==0))||\
-    [info exists arguments(-h)]\
-} {
+if {(![info exists arguments(-f)]&&([llength $argv]==0))||[info exists arguments(-h)]} {
     printUsage 1
 }
 
@@ -60,10 +57,7 @@ proc loadModules {modules} {
             puts stderr "$::argv0: module \"$module\" was specified more than once"
             exit 1
         }
-        if {[catch {package require $module}]} {
-            puts stderr "$::argv0: could not load package \"$module\""
-            exit 1
-        }
+        package require $module                                                                             ;# module is loaded here
         set loaded($module) {}
         if {![info exists ${module}::data(indexColumns)]} {
             set ${module}::data(indexColumns) 0                                ;# use first column as single index column by default
@@ -133,7 +127,7 @@ proc commaSeparatedString {words} {
 }
 
 
-if {[catch {package require stooop 3.6.1}]} {
+if {[catch {package require stooop 3.7}]} {
     source stooop.tcl                                                                     ;# in case stooop package is not installed
 }
 namespace import stooop::*
@@ -141,7 +135,7 @@ if {[catch {package require switched 1.4}]} {
     source switched.tcl
 }
 
-if {[catch {package require scwoop 2.5}]} {
+if {[catch {package require scwoop 2.6}]} {
     source scwoutil.tcl
     source scwoop.tcl                                                                     ;# in case scwoop package is not installed
     source bindings.tcl
@@ -157,7 +151,8 @@ if {[info exists arguments(-f)]} {
     set saveFile $arguments(-f)
     set initializer [new record -file $saveFile]
     record::read $initializer
-    set modules(all) [record::modules $initializer]
+    set modules(initialized) [record::modules $initializer]
+    set modules(all) [concat $argv $modules(initialized)] ;# load uninitialized modules 1st so that their tables are placed properly
 } else {
     set saveFile {}
     set modules(all) $argv
@@ -189,7 +184,7 @@ if {[info exists arguments(-p)]} {
 if {[catch {package require Tktable 2}]} {                                               ;# in case tkTable package is not installed
     switch $tcl_platform(platform) {
         unix {
-            load ./Tktable.so.2.3
+            load ./Tktable.so.2.4
         }
         windows {
             load ./tktable.dll
@@ -209,7 +204,7 @@ if {[catch {package require BLT}]} {
 }
 set officialBLT [expr {$blt_version!=8.0}]                                               ;# remember which BLT version is being used
 
-if {[catch {package require tkpiechart 5.2}]} {                                       ;# in case tkpiechart package is not installed
+if {[catch {package require tkpiechart 5.2.1}]} {                                     ;# in case tkpiechart package is not installed
     source pielabel.tcl
     source boxlabel.tcl
     source canlabel.tcl
@@ -258,7 +253,7 @@ proc updateTitle {} {                                                          ;
 }
 
 proc createMenuWidget {parentPath readOnly includePollTime} {
-    global modules
+    global modules static
 
     set menu [menu $parentPath.menu -tearoff 0]
     $menu add cascade -label File -menu [menu $menu.file -tearoff 0] -underline 0
@@ -274,6 +269,21 @@ proc createMenuWidget {parentPath readOnly includePollTime} {
         $menu add cascade -label Options -menu [menu $menu.options -tearoff 0] -underline 0
         $menu.options add command -label {Poll Time...} -command inquirePollTime -underline 0
     }
+    if {!$readOnly} {
+        $menu add cascade -label New -menu [menu $menu.new -tearoff 0] -underline 0
+        $menu.new add command -label {Graph Chart...} -underline 0 -command "createCellsViewer dataGraph {} 1 $static \$pollTime"
+if {$::officialBLT} {
+        $menu.new add command -label {Overlap Bar Chart...} -underline 0\
+            -command "createCellsViewer dataOverlapBarChart {} 1 $static"
+}
+        $menu.new add command -label {Side Bar Chart...} -underline 5 -command "createCellsViewer dataSideBarChart {} 1 $static"
+        $menu.new add command -label {Stacked Bar Chart...} -underline 0\
+            -command "createCellsViewer dataStackedBarChart {} 1 $static"
+        $menu.new add command -label {2D Pie Chart...} -underline 0 -command "createCellsViewer data2DPieChart {} 1 $static"
+        $menu.new add command -label {3D Pie Chart...} -underline 0 -command "createCellsViewer data3DPieChart {} 1 $static"
+        $menu.new add command -label {Summary Table...} -underline 8 -command "createCellsViewer summaryTable {} 1 $static"
+        $menu.new add command -label {Free Text...} -underline 0 -command "createCellsViewer freeText {} 1 $static"
+    }
     $menu add cascade -label Help -menu [menu $menu.help -tearoff 0] -underline 0
     $menu.help add command -label Global... -underline 0 -accelerator F1 -command helpWindow
     bind $parentPath <F1> helpWindow
@@ -315,6 +325,10 @@ proc manageViewer {viewer destroyable args} {                         ;# argumen
     }
 }
 
+proc dragEcho {data format} {
+    return $data
+}
+
 proc createDragAndDropZone {parentPath} {
     global canvas pollTime static
 
@@ -324,46 +338,62 @@ proc createDragAndDropZone {parentPath} {
     pack $label -pady 1 -side left
     new dropSite -path $label -formats DATACELLS\
         -command "createCellsViewer dataGraph \$dragSite::data(DATACELLS) 1 $static \$pollTime"
-    new widgetTip -path $label -text {graph drop site}
+    new widgetTip -path $label -text "graph chart\ndrag'n'drop site"
+    set drag [new dragSite -path $label]
+    dragSite::provide $drag VIEWER {dragEcho ::dataGraph}
 
 if {$::officialBLT} {
     set label [label $frame.overlapBarChart -image [image create photo -data [dataOverlapBarChart::iconData]]]
     pack $label -pady 1 -side left
     new dropSite -path $label -formats DATACELLS\
         -command "createCellsViewer dataOverlapBarChart \$dragSite::data(DATACELLS) 1 $static"
-    new widgetTip -path $label -text {overlap bar chart drop site}
+    new widgetTip -path $label -text "overlap bar chart\ndrag'n'drop site"
+    set drag [new dragSite -path $label]
+    dragSite::provide $drag VIEWER {dragEcho ::dataOverlapBarChart}
 }
 
     set label [label $frame.sideBarChart -image [image create photo -data [dataSideBarChart::iconData]]]
     pack $label -pady 1 -side left
     new dropSite -path $label -formats DATACELLS -command "createCellsViewer dataSideBarChart \$dragSite::data(DATACELLS) 1 $static"
-    new widgetTip -path $label -text {side bar chart drop site}
+    new widgetTip -path $label -text "side bar chart\ndrag'n'drop site"
+    set drag [new dragSite -path $label]
+    dragSite::provide $drag VIEWER {dragEcho ::dataSideBarChart}
 
     set label [label $frame.stackedBarChart -image [image create photo -data [dataStackedBarChart::iconData]]]
     pack $label -pady 1 -side left
     new dropSite -path $label -formats DATACELLS\
         -command "createCellsViewer dataStackedBarChart \$dragSite::data(DATACELLS) 1 $static"
-    new widgetTip -path $label -text {stacked bar chart drop site}
+    new widgetTip -path $label -text "stacked bar chart\ndrag'n'drop site"
+    set drag [new dragSite -path $label]
+    dragSite::provide $drag VIEWER {dragEcho ::dataStackedBarChart}
 
     set label [label $frame.2DPieChart -image [image create photo -data [data2DPieChart::iconData]]]
     pack $label -pady 1 -side left
     new dropSite -path $label -formats DATACELLS -command "createCellsViewer data2DPieChart \$dragSite::data(DATACELLS) 1 $static"
-    new widgetTip -path $label -text {2D pie chart drop site}
+    new widgetTip -path $label -text "2D pie chart\ndrag'n'drop site"
+    set drag [new dragSite -path $label]
+    dragSite::provide $drag VIEWER {dragEcho ::data2DPieChart}
 
     set label [label $frame.3DPieChart -image [image create photo -data [data3DPieChart::iconData]]]
     pack $label -pady 1 -side left
     new dropSite -path $label -formats DATACELLS -command "createCellsViewer data3DPieChart \$dragSite::data(DATACELLS) 1 $static"
-    new widgetTip -path $label -text {3D pie chart drop site}
+    new widgetTip -path $label -text "3D pie chart\ndrag'n'drop site"
+    set drag [new dragSite -path $label]
+    dragSite::provide $drag VIEWER {dragEcho ::data3DPieChart}
 
     set label [label $frame.summaryTable -image [image create photo -data [summaryTable::iconData]]]
     pack $label -pady 1 -side left
     new dropSite -path $label -formats DATACELLS -command "createCellsViewer summaryTable \$dragSite::data(DATACELLS) 1 $static"
-    new widgetTip -path $label -text {summary table drop site}
+    new widgetTip -path $label -text "summary table\ndrag'n'drop site"
+    set drag [new dragSite -path $label]
+    dragSite::provide $drag VIEWER {dragEcho ::summaryTable}
 
     set label [label $frame.freeText -image [image create photo -data [freeText::iconData]]]
     pack $label -pady 1 -side left
     new dropSite -path $label -formats DATACELLS -command "createCellsViewer freeText \$dragSite::data(DATACELLS) 1 $static"
-    new widgetTip -path $label -text {free text drop site}
+    new widgetTip -path $label -text "free text\ndrag'n'drop site"
+    set drag [new dragSite -path $label]
+    dragSite::provide $drag VIEWER {dragEcho ::freeText}
 
     set trashData {
         R0lGODlhKAAoAKUAAP8A/8/Lz+/r71FRUZ6anpaSlv/7/wgICL66vkFBQYaChtfT17LA3LaytjAwMFlZWZaant/b3/fz96aipnFxcWlpaWFhYTAoKCAgICgo
@@ -380,7 +410,10 @@ if {$::officialBLT} {
     set label [label $frame.trash -image [image create photo -data $trashData]]
     pack $label -pady 1 -side right
     new dropSite -path $label -formats OBJECTS -command "eval delete \$dragSite::data(OBJECTS)"
-    new widgetTip -path $label -text {objects trash drop site}
+    new widgetTip -path $label -text "objects trashing\ndrag'n'drop site"
+    set drag [new dragSite -path $label]
+    dragSite::provide $drag KILL list                                           ;# drag data is unimportant, only the kill action is
+
     return $frame
 }
 
@@ -501,7 +534,7 @@ foreach module $modules(all) {
         } else {                                                                                     ;# use single default data view
             set table [new dataTable $canvas -data ${module}::data -draggable $draggable]
         }
-        if {[info exists initializer]} {
+        if {[info exists initializer]&&([lsearch -exact $module $modules(initialized)]>=0)} {
             eval composite::configure $table [record::tableOptions $initializer $module $index]
             # use stored window manager initialization data for table
             foreach {x y width height level} [record::tableWindowManagerData $initializer $module $index] {}
